Enum push_trait::Nothing
[−]
[src]
pub enum Nothing {}Represents that no value is ever pushed out on a push.
Currently, the ! type is only available on nightly. As a result, when the nightly feature
isn't enabled, this enum is used in place of ! to represent that no object can ever be pushed
out when a push happens.