Trait push_trait::PushBack
[−]
[src]
pub trait PushBack<T>: Push<T> { fn push_back(&mut self, val: T) -> Option<Self::PushedOut>; }
A mutable collection onto which items can be added "at the end."
"At the end" is defined in a way such that truncating the collection down by the item's length after a push will remove the item.
Required Methods
fn push_back(&mut self, val: T) -> Option<Self::PushedOut>
Adds the value to the back of the collection.
Implementors
impl<T> PushBack<T> for LinkedList<T>impl<T> PushBack<LinkedList<T>> for LinkedList<T>impl PushBack<char> for Stringimpl<T> PushBack<T> for Vec<T>impl<T> PushBack<T> for VecDeque<T>impl PushBack<bool> for BitVecimpl<T> PushBack<T> for BList<T>impl<K: Hash + Eq, V> PushBack<(K, V)> for LinkedHashMap<K, V>impl<K: Hash + Eq, V> PushBack<(K, V)> for LruCache<K, V>